==> ?url=gopher%3A%2F%2Fftp.icm.edu.pl%3A70%2F9%2Fvol%2Frzm8%2Fzebra%2Ficmarch%2Fzebra-0.71.tar.gz: zebra-0.71/zebra/client_main.c <==
/*
 * $Id: client_main.c,v 1.33 1999/02/19 17:26:36 developer Exp $
 *
 * GNU Zebra client test main routine.
 * Copyright (C) 1997 Kunihiro Ishiguro
 *
 * This file is part of GNU Zebra.
 *
 * GNU Zebra is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * GNU Zebra is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Zebra; see the file COPYING.  If not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  
 */

#include <zebra.h>

#include "zebra/zebra.h"
#include "prefix.h"
#include "client.h"

/* Zebra socket. */
int sock;

/* IPv4 route add and delete test. */
void
zebra_test_ipv4 (int command, int type, char *prefix, char *gateway)
{
  struct prefix_ipv4 p;
  struct in_addr gate;

  str2prefix_ipv4 (prefix, &p);
  inet_aton (gateway, &gate);
  
  switch (command)
    {
    case ZEBRA_IPV4_ROUTE_ADD:
      zebra_ipv4_add (sock, type, 0, &p, &gate, 0);
      break;
    case ZEBRA_IPV4_ROUTE_DELETE:
      zebra_ipv4_delete (sock, type, 0, &p, &gate, 0);
      break;
    }
}

#ifdef HAVE_IPV6
/* IPv6 route add and delete test. */
void
zebra_test_v6 (int sock)
{
  struct prefix_ipv6 p;
  struct in6_addr nexthop;

  str2prefix_ipv6 ("3ffe:506::2/128", &p);
  inet_pton (AF_INET6, "::1", &nexthop);

  zebra_ipv6_add (sock, ZEBRA_ROUTE_STATIC, &p, &nexthop, 1);

  sleep (5);
  zebra_ipv6_delete (sock, ZEBRA_ROUTE_STATIC, &p, &nexthop, 1);
}
#endif /* HAVE_IPV6 */

/* Print out usage and exit. */
void
usage_exit ()
{
  fprintf (stderr, "Usage: client filename\n");
  exit (1);
}

struct zebra_info {
  char *str;
  int type;
} zebra_type[] = 
{
  { "static", ZEBRA_ROUTE_STATIC },
  { "rip",    ZEBRA_ROUTE_RIP },
  { "ripng",  ZEBRA_ROUTE_RIPNG },
  { "bgp",    ZEBRA_ROUTE_BGP },
  { NULL,     0 }
};

/* Zebra route simulator. */
void
zebra_sim (FILE *fp)
{
  char buf[1024];

  while (fgets (buf, sizeof buf, fp))
    {
      int i;
      int ret;
      int type;
      char str[BUFSIZ], command[BUFSIZ], prefix[BUFSIZ], gateway[BUFSIZ];

      if (*buf == '#')
	continue;

      type = ZEBRA_ROUTE_STATIC;

      ret = sscanf (buf, "%s %s %s %s\n", command, str, prefix, gateway);
      if (ret != 4)
	{
	  ret = sscanf (buf, "%s %s %s\n", command, prefix, gateway);
	  printf ("matched %d : %s %s %s\n", ret, command, prefix, gateway);
	  if (ret != 3)
	    continue;
	}
      else
	{
	  for (i = 0; i < 10; i++)
	    {
	      if (!zebra_type[i].str)
		break;
	      if (strcmp (zebra_type[i].str, str) == 0)
		{
		  type = zebra_type[i].type;
		  break;
		}
	    }
	}
  
      if (strcmp (command, "add") == 0)
	{
	  zebra_test_ipv4 (ZEBRA_IPV4_ROUTE_ADD, type, prefix, gateway);
	  continue;
	}

      if (strcmp (command, "del") == 0)
	{
	  zebra_test_ipv4 (ZEBRA_IPV4_ROUTE_DELETE, type, prefix, gateway);
	  continue;
	}
    }
}

/* Test zebra client main routine. */
int
main (int argc, char **argv)
{
  FILE *fp;

  if (argc == 1)
      usage_exit ();

  /* Establish connection to zebra. */
  sock = zebra_connect ();
  if (sock < 0) 
    {
      fprintf (stderr, "Can't connect to zebra daemon\n");
      exit (1);
    }

  /* Open simulation file. */
  fp = fopen (argv[1], "r");
  if (fp == NULL)
    {
      fprintf (stderr, "can't open %s\n", argv[1]);
      exit (1);
    }

  /* Do main work. */
  zebra_sim (fp);

  fclose (fp);
  close (sock);
  exit (0);
}

==> ?url=gopher%3A%2F%2Fftp.icm.edu.pl%3A70%2F9%2Fvol%2Frzm8%2Fzebra%2Ficmarch%2Fzebra-0.75.tar.gz: zebra-0.75/zebra/client_main.c <==
/*
 * $Id: client_main.c,v 1.33 1999/02/19 17:26:36 developer Exp $
 *
 * GNU Zebra client test main routine.
 * Copyright (C) 1997 Kunihiro Ishiguro
 *
 * This file is part of GNU Zebra.
 *
 * GNU Zebra is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * GNU Zebra is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Zebra; see the file COPYING.  If not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  
 */

#include <zebra.h>

#include "zebra/zebra.h"
#include "prefix.h"
#include "client.h"

/* Zebra socket. */
int sock;

/* IPv4 route add and delete test. */
void
zebra_test_ipv4 (int command, int type, char *prefix, char *gateway)
{
  struct prefix_ipv4 p;
  struct in_addr gate;

  str2prefix_ipv4 (prefix, &p);
  inet_aton (gateway, &gate);
  
  switch (command)
    {
    case ZEBRA_IPV4_ROUTE_ADD:
      zebra_ipv4_add (sock, type, ZEBRA_FLAGS_INTERNAL, &p, &gate, 0);
      break;
    case ZEBRA_IPV4_ROUTE_DELETE:
      zebra_ipv4_delete (sock, type, ZEBRA_FLAGS_INTERNAL, &p, &gate, 0);
      break;
    }
}

#ifdef HAVE_IPV6
/* IPv6 route add and delete test. */
void
zebra_test_v6 (int sock)
{
  struct prefix_ipv6 p;
  struct in6_addr nexthop;

  str2prefix_ipv6 ("3ffe:506::2/128", &p);
  inet_pton (AF_INET6, "::1", &nexthop);

  zebra_ipv6_add (sock, ZEBRA_ROUTE_STATIC, 0, &p, &nexthop, 1);

  sleep (5);
  zebra_ipv6_delete (sock, ZEBRA_ROUTE_STATIC, 0, &p, &nexthop, 1);
}
#endif /* HAVE_IPV6 */

/* Print out usage and exit. */
void
usage_exit ()
{
  fprintf (stderr, "Usage: client filename\n");
  exit (1);
}

struct zebra_info {
  char *str;
  int type;
} zebra_type[] = 
{
  { "static", ZEBRA_ROUTE_STATIC },
  { "rip",    ZEBRA_ROUTE_RIP },
  { "ripng",  ZEBRA_ROUTE_RIPNG },
  { "bgp",    ZEBRA_ROUTE_BGP },
  { NULL,     0 }
};

/* Zebra route simulator. */
void
zebra_sim (FILE *fp)
{
  char buf[1024];

  while (fgets (buf, sizeof buf, fp))
    {
      int i;
      int ret;
      int type;
      char str[BUFSIZ], command[BUFSIZ], prefix[BUFSIZ], gateway[BUFSIZ];

      if (*buf == '#')
	continue;

      type = ZEBRA_ROUTE_STATIC;

      ret = sscanf (buf, "%s %s %s %s\n", command, str, prefix, gateway);
      if (ret != 4)
	{
	  ret = sscanf (buf, "%s %s %s\n", command, prefix, gateway);
	  printf ("matched %d : %s %s %s\n", ret, command, prefix, gateway);
	  if (ret != 3)
	    continue;
	}
      else
	{
	  for (i = 0; i < 10; i++)
	    {
	      if (!zebra_type[i].str)
		break;
	      if (strcmp (zebra_type[i].str, str) == 0)
		{
		  type = zebra_type[i].type;
		  break;
		}
	    }
	}
  
      if (strcmp (command, "add") == 0)
	{
	  zebra_test_ipv4 (ZEBRA_IPV4_ROUTE_ADD, type, prefix, gateway);
	  continue;
	}

      if (strcmp (command, "del") == 0)
	{
	  zebra_test_ipv4 (ZEBRA_IPV4_ROUTE_DELETE, type, prefix, gateway);
	  continue;
	}
    }
}

/* Test zebra client main routine. */
int
main (int argc, char **argv)
{
  FILE *fp;

  if (argc == 1)
      usage_exit ();

  /* Establish connection to zebra. */
  sock = zebra_connect ();
  if (sock < 0) 
    {
      fprintf (stderr, "Can't connect to zebra daemon\n");
      exit (1);
    }

  /* Open simulation file. */
  fp = fopen (argv[1], "r");
  if (fp == NULL)
    {
      fprintf (stderr, "can't open %s\n", argv[1]);
      exit (1);
    }

  /* Do main work. */
  zebra_sim (fp);

  fclose (fp);
  close (sock);
  exit (0);
}
